# meta_tools

## Installation

To install the project locally, run

```bash
pip install .
```

## Usage

Run the following for basic usage information:

```bash
reify -h
```

To generate and open the documentation, run

```bash
mkdocs serve -o
```

Make sure to install the optional documentation dependencies via

```bash
pip install .[doc]
```

Instructions to install and use `nox` can be found in
[DEVELOPMENT.md](./DEVELOPMENT.md)
